use v6-alpha;


class Foo;

method foo { "foo" }
